@@ -15,7 +15,9 @@ This module contains procedures for reading and writing various ARM datasets.
     armfiles.create_obj_from_arm_dod
     armfiles.read_netcdf
     csvfiles.read_csv
+    mpl.read_sigma_mplv5
 """
 
 from . import armfiles
 from . import csvfiles
+from . import mpl
