@@ -6,18 +6,24 @@ def test_get_stability_indices():
     sonde_ds = act.io.armfiles.read_netcdf(
         act.tests.sample_files.EXAMPLE_SONDE1)
 
-    sonde_ds = act.retrievals.calculate_stability_indicies(
-        sonde_ds, temp_name="tdry", td_name="dp", p_name="pres")
-    assert sonde_ds["lifted_index"].units == "kelvin"
-    np.testing.assert_almost_equal(sonde_ds["lifted_index"], 28.4639, decimal=3)
-    np.testing.assert_almost_equal(sonde_ds["most_unstable_cin"], 0.000, decimal=3)
-    np.testing.assert_almost_equal(sonde_ds["surface_based_cin"], 0.000, decimal=3)
-    np.testing.assert_almost_equal(sonde_ds["most_unstable_cape"], 0.000, decimal=3)
-    np.testing.assert_almost_equal(sonde_ds["surface_based_cape"], 1.628, decimal=3)
-    np.testing.assert_almost_equal(
-        sonde_ds["lifted_condensation_level_pressure"], 927.143, decimal=3)
-    np.testing.assert_almost_equal(
-        sonde_ds["lifted_condensation_level_temperature"], -8.079, decimal=3)
+    try:
+        sonde_ds = act.retrievals.calculate_stability_indicies(
+            sonde_ds, temp_name="tdry", td_name="dp", p_name="pres")
+        metpy = True
+    except Exception:
+        metpy = False
+
+    if metpy is True:
+        assert sonde_ds["lifted_index"].units == "kelvin"
+        np.testing.assert_almost_equal(sonde_ds["lifted_index"], 28.4639, decimal=3)
+        np.testing.assert_almost_equal(sonde_ds["most_unstable_cin"], 0.000, decimal=3)
+        np.testing.assert_almost_equal(sonde_ds["surface_based_cin"], 0.000, decimal=3)
+        np.testing.assert_almost_equal(sonde_ds["most_unstable_cape"], 0.000, decimal=3)
+        np.testing.assert_almost_equal(sonde_ds["surface_based_cape"], 1.628, decimal=3)
+        np.testing.assert_almost_equal(
+            sonde_ds["lifted_condensation_level_pressure"], 927.143, decimal=3)
+        np.testing.assert_almost_equal(
+            sonde_ds["lifted_condensation_level_temperature"], -8.079, decimal=3)
     sonde_ds.close()
 
 
